#!/bin/sh
export PATH=/bin:/usr/bin:/sbin:/usr/sbin
if linuxconf --silent --modulemain dhcpd --updatedns $@ >/dev/null 2>/dev/null
then
	if [ -x /usr/sbin/named.reload ] ; then
		/usr/sbin/named.reload >/dev/null
	elif [ -x /usr/sbin/named.restart ] ; then
		/usr/sbin/named.restart >/dev/null
	elif [ -x /usr/sbin/ndc ] ; then
		/usr/sbin/ndc reload >/dev/null
	else
		echo Don\'t know how to restart the DNS on the system  >&2
	fi
fi
